# Emploi_IA

![Version](https://img.shields.io/badge/version-1.0.0-blue.svg)
![Statut du Projet](https://img.shields.io/badge/statut-En%20D%C3%A9veloppement-orange.svg)
[![License](https://img.shields.io/badge/License-MIT-green.svg)](LICENSE) ---

## 🚀 Vue d'Ensemble du Projet

**Emploi_IA** est une plateforme web intelligente et innovante dédiée à la **recherche d'emploi et à l'évolution professionnelle en France**. Propulsée par l'intelligence artificielle et enrichie par l'intégration des **APIs officielles de France Travail** (anciennement Pôle Emploi) et d'autres partenaires, Emploi_IA a pour mission de simplifier, personnaliser et dynamiser le parcours de chaque professionnel.

Inspirée par les principes de simplicité et d'efficacité de **Google Careers**, notre plateforme vise à fournir des **matchs emploi-profil pertinents**, des **insights précis sur le marché du travail** et des **conseils proactifs** pour une prise de décision éclairée.

---

## ✨ Fonctionnalités Clés (MVP et au-delà)

* **Recherche d'Offres Intelligente :** Trouvez rapidement les offres d'emploi les plus pertinentes grâce à des filtres avancés et une recherche par mots-clés/localisation.
* **Matching IA Personnalisé :** Un moteur d'intelligence artificielle analyse votre profil (compétences, métiers ROME) et les offres pour vous proposer les meilleures correspondances avec un indicateur de pertinence clair.
* **Profil Utilisateur Enrichi :** Gérez vos compétences, vos expériences et vos préférences pour une personnalisation accrue des recommandations.
* **Outils d'Aide à la Candidature :** Génération de lettres de motivation, mise en favoris d'offres.
* **Insights Marché (Phases futures) :** Accédez à des données statistiques sur l'emploi, les métiers en tension et les entreprises qui recrutent.
* **Orientation et Formation (Phases futures) :** Suggestions de formations et de parcours de carrière basés sur l'analyse de vos compétences et du marché.

---

## 🛠️ Technologies & Intégrations

### Stack Technique :

### Stack Technique :

* **Backend :** **Python 🐍 (avec FastAPI)**
    * *Pourquoi ce choix :* Python est le langage de prédilection pour l'**intégration, l'orchestration et l'exploitation de services d'intelligence artificielle externes** (comme les APIs de Mistral et Google Gemini) ainsi que pour la **gestion et le traitement de données complexes**. C'est crucial pour notre moteur de matching, l'analyse des référentiels ROME, la génération de contenu, et l'exploitation des APIs de France Travail. FastAPI, un framework Python moderne et performant, nous permet de construire des APIs rapides et robustes, avec une excellente gestion de l'asynchronisme. Cette combinaison garantit une solution évolutive, maintenable et "future-proof", capable de gérer efficacement les interactions avec de multiples services IA et de traiter de grands volumes de données.
* **Base de Données :** PostgreSQL (pour sa robustesse, sa scalabilité et son support natif des données structurées/JSON).
* **Frontend :** **React ⚛️**
    * *Pourquoi ce choix :* React, développé par Meta (Facebook), est le framework JavaScript le plus largement adopté et le plus populaire pour la construction d'interfaces utilisateur interactives et performantes. Son approche par composants, sa flexibilité et son immense écosystème de librairies et d'outils garantissent une capacité à créer une expérience utilisateur fluide et intuitive, tout en assurant la scalabilité et la maintenabilité du code. C'est un choix solide et "future-proof" pour une application web moderne et ambitieuse comme Emploi_IA, offrant également un très vaste bassin de talents pour le développement et une forte communauté.
### APIs Intégrées (France Travail et Partenaires) :

Emploi_IA s'appuie sur une intégration profonde avec les APIs suivantes pour offrir des données fiables et à jour :

* `Offres d'emploi`
* `ROME 4.0 (Métiers, Compétences, Situations de travail, Fiches ROME)`
* `Romeo` (Moteur d'IA)
* `La Bonne Boîte`
* `Marché du travail`
* `Open formation`
* `Sortants de formation et accès à l'emploi`
* `Mes évènements France Travail`
* Et bientôt l'intégration **SSO France Travail** pour une connexion simplifiée !

---

## 📂 Structure du Projet

Le dépôt est organisé de manière claire pour faciliter la navigation et la collaboration :

* `./docs/` : Contient toute la documentation du projet.
    * `./docs/api/` : Spécifications OpenAPI/Swagger de toutes les APIs France Travail utilisées (`.json`).
    * `./docs/ROADMAP.md` : La feuille de route détaillée du projet, décrivant les phases de développement.
    * `./docs/PRD.md` : Le Product Requirements Document, détaillant les exigences fonctionnelles et non-fonctionnelles.
* `./src/` : Le dossier principal du code source de l'application (ou d'autres dossiers comme `backend/`, `frontend/` selon l'architecture).
* `./README.md` : Ce document, présentant une vue d'ensemble du projet.

---

## 🤝 Contribution (À Venir)

Nous sommes ouverts aux contributions ! Si vous souhaitez participer au développement d'Emploi_IA, veuillez consulter nos futures directives de contribution.

---

## 🚀 Lancement Local (Pour les Développeurs)

Pour lancer le projet en local :

1.  **Cloner le dépôt :**
    ```bash
    git clone [https://git.wilmoredynamics.com/ab/emploi_ia.git)
    cd emploi_ia
    ```
2.  **Configuration des APIs :**
    * Assurez-vous d'avoir obtenu les clés d'accès aux APIs France Travail.
    * Créez un fichier `.env` à la racine du projet et ajoutez vos clés API (voir `/.env.example` pour un template).
3.  **Installation des dépendances :**
    ```bash
    # Pour le backend (Python avec FastAPI)
    cd backend # Adaptez le chemin si votre backend est dans un sous-dossier comme 'backend/'
    pip install -r requirements.txt
    cd ..

    # Pour le frontend (React)
    cd frontend # Adaptez le chemin si votre frontend est dans un sous-dossier comme 'frontend/'
    npm install # ou yarn install
    cd ..
    ```
4.  **Lancer l'application :**
    ```bash
    # Pour le backend (exemple avec FastAPI)
    uvicorn backend.main:app --reload # Adaptez le chemin et le nom du fichier d'entrée de votre application FastAPI

    # Pour le frontend (React)
    cd frontend
    npm start # ou yarn start
    ```
    Votre application sera accessible sur `http://localhost:XXXX`.

---

## 📄 Licence

Ce projet est sous licence [MIT](LICENSE).

---

## 📧 Contact

Pour toute question ou information supplémentaire, n'hésitez pas à nous contacter à [contact@wilmoredynamics.com](mailto:contact@wilmoredynamics.com).

---